@@ -30,17 +30,18 @@ Options:
   --remove                      Remove remote file.
   -s --stream                   Streaming mode.
   -t --track                    Track transfer progress.
+  --use-password                Use password identification.
   --user=USER                   Username.
   --version                     Show version.
 
 """
 
-__version__ = '0.0.17'
+__version__ = '0.0.18'
 
 
 from ConfigParser import NoSectionError, SafeConfigParser
 from contextlib import contextmanager
-from getpass import getuser
+from getpass import getpass, getuser
 from os import fdopen, makedirs, remove
 from os.path import abspath, exists, expanduser, join
 from sys import stderr, stdin, stdout
@@ -82,7 +83,7 @@ class Client(object):
   #: Path to configuration file
   config_file = join(expanduser('~'), '.config', 'igloo', 'config')
 
-  def __init__(self, profile, **kwargs):
+  def __init__(self, profile, use_password, **kwargs):
     self.config = self.load_config(
       profile,
       {k: v for k, v in kwargs.items() if not v is None}
@@ -93,6 +94,7 @@ class Client(object):
       self.config['root_folder'],
       self.config.get('folder', None) or self.config['default_folder'],
     )))
+    self.use_password = use_password
 
   @contextmanager
   def get_sftp_client(self):
@@ -100,7 +102,14 @@ class Client(object):
     self.ssh = SSHClient()
     self.ssh.load_host_keys(join(expanduser('~'), '.ssh', 'known_hosts'))
     try:
-      self.ssh.connect(self.config['host'], username=self.config['user'])
+      if self.use_password:
+        self.ssh.connect(
+          self.config['host'],
+          username=self.config['user'],
+          password=getpass(),
+        )
+      else:
+        self.ssh.connect(self.config['host'], username=self.config['user'])
       try:
         self.sftp = self.ssh.open_sftp()
       except Exception:
@@ -229,6 +238,7 @@ def main():
   try:
     client = Client(
       profile=arguments['--profile'],
+      use_password=arguments['--use-password'],
       user=arguments['--user'],
       host=arguments['--host'],
       folder=arguments['--folder'],
